==> rhapsodie_0.1.2.tar.gz: rhapsodie-0.1.2/inc/stringhash.h <==
/*************************************************************************}
{ stringhash.h - class for string replacements by hash                    }
{                                                                         }
{ (c) Alexey Parfenov, 2011                                               }
{                                                                         }
{ e-mail: zxed@alkatrazstudio.net                                         }
{                                                                         }
{ This library is free software; you can redistribute it and/or           }
{ modify it under the terms of the GNU General Public License             }
{ as published by the Free Software Foundation; either version 3 of       }
{ the License, or (at your option) any later version.                     }
{                                                                         }
{ This library is distributed in the hope that it will be useful,         }
{ but WITHOUT ANY WARRANTY; without even the implied warranty of          }
{ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU        }
{ General Public License for more details.                                }
{                                                                         }
{ You may read GNU General Public License at:                             }
{   http://www.gnu.org/copyleft/gpl.html                                  }
{                                                                         }
{ last modified: 28 Jun 2011                                              }
{*************************************************************************/

#ifndef STRINGHASH_H
#define STRINGHASH_H

#include <QHash>
#include <QString>

class StringHash : public QObject, public QHash<QString, QString>
{
    Q_OBJECT
public:
    StringHash():QHash<QString, QString>(){}

    QString replaceInString(const QString& string);
};

#endif // STRINGHASH_H

==> rhapsodie_0.2.0.tar.gz: rhapsodie-0.2.0/inc/stringhash.h <==
/*************************************************************************}
{ stringhash.h - class for string replacements by hash                    }
{                                                                         }
{ (c) Alexey Parfenov, 2011                                               }
{                                                                         }
{ e-mail: zxed@alkatrazstudio.net                                         }
{                                                                         }
{ This library is free software; you can redistribute it and/or           }
{ modify it under the terms of the GNU General Public License             }
{ as published by the Free Software Foundation; either version 3 of       }
{ the License, or (at your option) any later version.                     }
{                                                                         }
{ This library is distributed in the hope that it will be useful,         }
{ but WITHOUT ANY WARRANTY; without even the implied warranty of          }
{ MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU        }
{ General Public License for more details.                                }
{                                                                         }
{ You may read GNU General Public License at:                             }
{   http://www.gnu.org/copyleft/gpl.html                                  }
{                                                                         }
{ last modified: 31 Mar 2012                                              }
{*************************************************************************/

#ifndef STRINGHASH_H
#define STRINGHASH_H

#include <QtCore>

class StringHash : public QObject, public QHash<QString, QString>
{
    Q_OBJECT
public:
    explicit StringHash():QHash<QString, QString>(){}

    QString replaceInString(const QString& string);
};

#endif // STRINGHASH_H
